@@ -24,7 +24,7 @@ class Plugin(Plugin_Base):
         "parse_files": ["ipynb"]
     }
 
-    def __init__(self, config, doc_src_path, site_config, logger = None):
+    def on_init(self, config, doc_src_path, site_config, logger = None):
         '''
             @config a dict object
             @logger teedoc.logger.Logger object
@@ -39,7 +39,7 @@ class Plugin(Plugin_Base):
 
         
 
-    def on_parse_files(self, files):
+    def on_parse_files(self, files, new_config=None):
         # result, format must be this
         result = {
             "ok": False,
@@ -73,8 +73,8 @@ class Plugin(Plugin_Base):
         result['ok'] = True
         return result
     
-    def on_parse_pages(self, files):
-        result = self.on_parse_files(files)
+    def on_parse_pages(self, files, new_config=None):
+        result = self.on_parse_files(files, new_config)
         return result
 
     
